==> nextcloud-13.0.1.tgz: nextcloud/lib/l10n/eu.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Ezin da idatzi \"config\" karpetan!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Hau normalean konpondu daitekesweb zerbitzarira config karpetan idazteko baimenak emanez",
    "See %s" : "Ikusi %s",
    "Sample configuration detected" : "Adibide-ezarpena detektatua",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Detektatu da adibide-ezarpena kopiatu dela. Honek zure instalazioa apur dezake eta ez da onartzen. Irakurri dokumentazioa config.php fitxategia aldatu aurretik.",
    "%1$s and %2$s" : "%1$s eta %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s eta %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s eta %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s eta %5$s",
    "PHP %s or higher is required." : "PHP %s edo berriagoa behar da.",
    "PHP with a version lower than %s is required." : "PHPren bertsioa %s baino txikiagoa izan behar da.",
    "Following databases are supported: %s" : "Hurrengo datubaseak onartzen dira: %s",
    "The command line tool %s could not be found" : "Komando lerroko %s tresna ezin da aurkitu",
    "The library %s is not available." : "%s liburutegia ez dago eskuragarri.",
    "Library %s with a version higher than %s is required - available version %s." : "%s liburutegiak %s baino bertsio handiagoa izan behar du - dagoen bertsioa %s.",
    "Library %s with a version lower than %s is required - available version %s." : "%s liburutegiak %s baino bertsio txikiagoa izan behar du - dagoen bertsioa %s.",
    "Following platforms are supported: %s" : "Hurrengo plataformak onartzen dira: %s",
    "Unknown filetype" : "Fitxategi mota ezezaguna",
    "Invalid image" : "Baliogabeko irudia",
    "Avatar image is not square" : "Abatarreko irudia ez da karratua",
    "today" : "gaur",
    "yesterday" : "atzo",
    "_%n day ago_::_%n days ago_" : ["orain dela egun %n","orain dela %n egun"],
    "last month" : "joan den hilabetean",
    "_%n month ago_::_%n months ago_" : ["orain dela hilabete %n","orain dela %n hilabete"],
    "last year" : "joan den urtean",
    "_%n year ago_::_%n years ago_" : ["orain dela urte %n","orain dela %n urte"],
    "_%n hour ago_::_%n hours ago_" : ["orain dela ordu %n","orain dela %n ordu"],
    "_%n minute ago_::_%n minutes ago_" : ["orain dela minutu %n","orain dela %n minutu"],
    "seconds ago" : "duela segundu batzuk",
    "File name is a reserved word" : "Fitxategi izena hitz erreserbatua da",
    "File name contains at least one invalid character" : "Fitxategi izenak behintzat baliogabeko karaktere bat du",
    "File name is too long" : "Fitxategi-izena luzeegia da",
    "Dot files are not allowed" : "Dot fitxategiak ez dira onartzen",
    "Empty filename is not allowed" : "Fitxategiaren izena izin da hutsa izan",
    "Help" : "Laguntza",
    "Apps" : "Aplikazioak",
    "Users" : "Erabiltzaileak",
    "Unknown user" : "Erabiltzaile ezezaguna",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Sharing" : "Partekatze",
    "Encryption" : "Enkriptazio",
    "Additional settings" : "Ezarpen gehiago",
    "Tips & tricks" : "Aholkuak eta trikimailuak",
    "__language_name__" : "Euskara",
    "%s enter the database username and name." : "%s sartu datu-basearen erabiltzaile-izena eta izena.",
    "%s enter the database username." : "%s sartu datu basearen erabiltzaile izena.",
    "%s enter the database name." : "%s sartu datu basearen izena.",
    "%s you may not use dots in the database name" : "%s ezin duzu punturik erabili datu basearen izenean.",
    "Oracle connection could not be established" : "Ezin da Oracle konexioa sortu",
    "Oracle username and/or password not valid" : "Oracle erabiltzaile edota pasahitza ez dira egokiak.",
    "PostgreSQL username and/or password not valid" : "PostgreSQL erabiltzaile edota pasahitza ez dira egokiak.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X-ek ez du sostengurik eta %s gaizki ibili daiteke plataforma honetan. Erabiltzekotan, zure ardurapean.",
    "For the best results, please consider using a GNU/Linux server instead." : "Emaitza hobeak izateko, mesedez gogoan hartu GNU/Linux zerbitzari bat erabiltzea.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Mesedez ezabatu open_basedir ezarpena zure php.ini-tik edo aldatu 64-biteko PHPra.",
    "Set an admin username." : "Ezarri administraziorako erabiltzaile izena.",
    "Set an admin password." : "Ezarri administraziorako pasahitza.",
    "Can't create or write into the data directory %s" : "Ezin da %s datu karpeta sortu edo bertan idatzi ",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "%s partekatzeak huts egin du, motorrak %i motako partekatzeak baimentzen ez dituelako",
    "Sharing %s failed, because the file does not exist" : "%s elkarbanatzeak huts egin du, fitxategia ez delako existitzen",
    "You are not allowed to share %s" : "Ez zadue %s elkarbanatzeko baimendua",
    "Sharing %s failed, because the user %s does not exist" : "%s elkarbanatzeak huts egin du, %s erabiltzailea existitzen ez delako",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s elkarbanatzeak huts egin du, %s erabiltzailea ez delako %s partaide den talderen bateko partaidea",
    "Sharing %s failed, because this item is already shared with %s" : "%s elkarbanatzeak huts egin du, dagoeneko %s erabiltzailearekin elkarbanatuta dagoelako",
    "Sharing %s failed, because the group %s does not exist" : "%s elkarbanatzeak huts egin du, %s taldea ez delako existitzen",
    "Sharing %s failed, because %s is not a member of the group %s" : "%s elkarbanatzeak huts egin du, %s ez delako %s taldearen partaidea",
    "You need to provide a password to create a public link, only protected links are allowed" : "Lotura publiko bat sortzeko pasahitza idatzi behar duzu, bakarrik babestutako loturak baimenduta daude",
    "Sharing %s failed, because sharing with links is not allowed" : "%s elkarbanatzeak huts egin du, lotura bidezko elkarbanatzea baimendua ez dagoelako",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s partekatzeak huts egin du, ezin da %s aurkitu, agian zerbitzaria orain ez dago eskuragarri.",
    "Share type %s is not valid for %s" : "%s elkarbanaketa mota ez da %srentzako egokia",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Ezin izan da jarri iraungitze data. Konpartitzea ezin da iraungi konpartitu eta %s ondoren.",
    "Cannot set expiration date. Expiration date is in the past" : "Ezin da jarri iraungitze data. Iraungitze data iragan da.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "%s elkarbanaketa motorra  OCP\\Share_Backend interfazea inplementatu behar du ",
    "Sharing backend %s not found" : "Ez da %s elkarbanaketa motorra aurkitu",
    "Sharing backend for %s not found" : "Ez da %srako elkarbanaketa motorrik aurkitu",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s elkarbanatzeak huts egin du, baimenak %sri emandakoak baino gehiago direlako",
    "Sharing %s failed, because resharing is not allowed" : "%s elkarbanatzeak huts egin du, ber-elkarbanatzea baimenduta ez dagoelako",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s elkarbanatzeak huts egin du, %sren elkarbanaketa motorrak bere iturria aurkitu ezin duelako",
    "Sharing %s failed, because the file could not be found in the file cache" : "%s elkarbanatzeak huts egin du, fitxategia katxean aurkitu ez delako",
    "%s shared »%s« with you" : "%s-ek »%s« zurekin partekatu du",
    "Could not find category \"%s\"" : "Ezin da \"%s\" kategoria aurkitu",
    "Sunday" : "Igandea",
    "Monday" : "Astelehena",
    "Tuesday" : "Asteartea",
    "Wednesday" : "Asteazkena",
    "Thursday" : "Osteguna",
    "Friday" : "Ostirala",
    "Saturday" : "Larunbata",
    "Sun." : "Ig.",
    "Mon." : "Al.",
    "Tue." : "Ar.",
    "Wed." : "Az.",
    "Thu." : "Og.",
    "Fri." : "Ol.",
    "Sat." : "Lr.",
    "Su" : "Ig",
    "Mo" : "Al",
    "Tu" : "Ar",
    "We" : "Az",
    "Th" : "Og",
    "Fr" : "Ol",
    "Sa" : "Lr",
    "January" : "Urtarrila",
    "February" : "Otsaila",
    "March" : "Martxoa",
    "April" : "Apirila",
    "May" : "Maiatza",
    "June" : "Ekaina",
    "July" : "Uztaila",
    "August" : "Abuztua",
    "September" : "Iraila",
    "October" : "Urria",
    "November" : "Azaroa",
    "December" : "Abendua",
    "Jan." : "Urt.",
    "Feb." : "Ots.",
    "Mar." : "Mar.",
    "Apr." : "Api.",
    "May." : "Mai.",
    "Jun." : "Eka.",
    "Jul." : "Uzt.",
    "Aug." : "Abu.",
    "Sep." : "Ira.",
    "Oct." : "Urr.",
    "Nov." : "Aza.",
    "Dec." : "Abe.",
    "A valid username must be provided" : "Baliozko erabiltzaile izena eman behar da",
    "A valid password must be provided" : "Baliozko pasahitza eman behar da",
    "The username is already being used" : "Erabiltzaile izena dagoeneko erabiltzen ari da",
    "User disabled" : "Erabiltzaile desgaituta",
    "Login canceled by app" : "Aplikazioa saioa bertan behera utzi du",
    "Application is not enabled" : "Aplikazioa ez dago gaituta",
    "Authentication error" : "Autentifikazio errorea",
    "Token expired. Please reload page." : "Tokena iraungitu da. Mesedez birkargatu orria.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ez dago datubaseen (sqlite, mysql edo postgresql) driverrik instalatuta.",
    "Cannot write into \"config\" directory" : "Ezin da idatzi \"config\" karpetan",
    "Cannot write into \"apps\" directory" : "Ezin da idatzi \"apps\" karpetan",
    "Setting locale to %s failed" : "Lokala %sra ezartzeak huts egin du",
    "Please install one of these locales on your system and restart your webserver." : "Instalatu hauetako lokal bat zure sisteman eta berrabiarazi zure web zerbitzaria.",
    "Please ask your server administrator to install the module." : "Mesedez eskatu zure zerbitzariaren kudeatzaileari modulua instala dezan.",
    "PHP module %s not installed." : "PHPren %s modulua ez dago instalaturik.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hau ziur aski cache/accelerator batek eragin du, hala nola Zend OPcache edo eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduluak instalatu dira, baina oraindik faltan bezala markatuta daude?",
    "Please ask your server administrator to restart the web server." : "Mesedez eskatu zerbitzariaren kudeatzaileari web zerbitzaria berrabiarazteko.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 behar da",
    "Please upgrade your database version" : "Mesedez eguneratu zure datu basearen bertsioa",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Mesedez aldatu baimenak 0770ra beste erabiltzaileek karpetan sartu ezin izateko.",
    "Could not obtain lock type %d on \"%s\"." : "Ezin da lortu sarraia mota %d \"%s\"-an."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5p1.tgz: nextcloud/lib/l10n/eu.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Ezin da idatzi \"config\" karpetan!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Hau normalean konpondu daitekesweb zerbitzarira config karpetan idazteko baimenak emanez",
    "See %s" : "Ikusi %s",
    "Sample configuration detected" : "Adibide-ezarpena detektatua",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Detektatu da adibide-ezarpena kopiatu dela. Honek zure instalazioa apur dezake eta ez da onartzen. Irakurri dokumentazioa config.php fitxategia aldatu aurretik.",
    "%1$s and %2$s" : "%1$s eta %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s eta %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s eta %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s eta %5$s",
    "PHP %s or higher is required." : "PHP %s edo berriagoa behar da.",
    "PHP with a version lower than %s is required." : "PHPren bertsioa %s baino txikiagoa izan behar da.",
    "Following databases are supported: %s" : "Hurrengo datubaseak onartzen dira: %s",
    "The command line tool %s could not be found" : "Komando lerroko %s tresna ezin da aurkitu",
    "The library %s is not available." : "%s liburutegia ez dago eskuragarri.",
    "Following platforms are supported: %s" : "Hurrengo plataformak onartzen dira: %s",
    "Unknown filetype" : "Fitxategi mota ezezaguna",
    "Invalid image" : "Baliogabeko irudia",
    "Avatar image is not square" : "Abatarreko irudia ez da karratua",
    "today" : "gaur",
    "tomorrow" : "bihar",
    "yesterday" : "atzo",
    "_%n day ago_::_%n days ago_" : ["orain dela egun %n","orain dela %n egun"],
    "last month" : "joan den hilabetean",
    "_%n month ago_::_%n months ago_" : ["orain dela hilabete %n","orain dela %n hilabete"],
    "last year" : "joan den urtean",
    "_%n year ago_::_%n years ago_" : ["orain dela urte %n","orain dela %n urte"],
    "_in %n hour_::_in %n hours_" : ["ordu %n barru","%n ordu barru"],
    "_%n hour ago_::_%n hours ago_" : ["orain dela ordu %n","orain dela %n ordu"],
    "_%n minute ago_::_%n minutes ago_" : ["orain dela minutu %n","orain dela %n minutu"],
    "seconds ago" : "duela segundu batzuk",
    "File name is a reserved word" : "Fitxategi izena hitz erreserbatua da",
    "File name contains at least one invalid character" : "Fitxategi izenak behintzat baliogabeko karaktere bat du",
    "File name is too long" : "Fitxategi-izena luzeegia da",
    "Dot files are not allowed" : "Dot fitxategiak ez dira onartzen",
    "Empty filename is not allowed" : "Fitxategiaren izena izin da hutsa izan",
    "__language_name__" : "Euskara",
    "Help" : "Laguntza",
    "Apps" : "Aplikazioak",
    "Settings" : "Ezarpenak",
    "Users" : "Erabiltzaileak",
    "Unknown user" : "Erabiltzaile ezezaguna",
    "Create" : "Sortu",
    "Change" : "Aldatu",
    "Delete" : "Ezabatu",
    "Share" : "Partekatu",
    "Basic settings" : "Oinarrizko ezarpenak",
    "Sharing" : "Partekatze",
    "Security" : "Segurtasuna",
    "Additional settings" : "Ezarpen gehiago",
    "Mobile & desktop" : "Mugikorra eta mahaigaina",
    "Unlimited" : "Mugagabea",
    "Verifying" : "Egiaztatzen",
    "Verify" : "Egiaztatu",
    "%s enter the database username and name." : "%s sartu datu-basearen erabiltzaile-izena eta izena.",
    "%s enter the database username." : "%s sartu datu basearen erabiltzaile izena.",
    "%s enter the database name." : "%s sartu datu basearen izena.",
    "%s you may not use dots in the database name" : "%s ezin duzu punturik erabili datu basearen izenean.",
    "Oracle connection could not be established" : "Ezin da Oracle konexioa sortu",
    "Oracle username and/or password not valid" : "Oracle erabiltzaile edota pasahitza ez dira egokiak.",
    "PostgreSQL username and/or password not valid" : "PostgreSQL erabiltzaile edota pasahitza ez dira egokiak.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X-ek ez du sostengurik eta %s gaizki ibili daiteke plataforma honetan. Erabiltzekotan, zure ardurapean.",
    "For the best results, please consider using a GNU/Linux server instead." : "Emaitza hobeak izateko, mesedez gogoan hartu GNU/Linux zerbitzari bat erabiltzea.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Mesedez kendu open_basedir ezarpena zure php.ini-tik edo aldatu 64-biteko PHPra.",
    "Set an admin username." : "Ezarri administraziorako erabiltzaile izena.",
    "Set an admin password." : "Ezarri administraziorako pasahitza.",
    "Can't create or write into the data directory %s" : "Ezin da %s datu karpeta sortu edo bertan idatzi ",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "%s partekatzeak huts egin du, motorrak %i motako partekatzeak baimentzen ez dituelako",
    "Sharing %s failed, because the file does not exist" : "%s elkarbanatzeak huts egin du, fitxategia ez delako existitzen",
    "You are not allowed to share %s" : "Ez zadue %s elkarbanatzeko baimendua",
    "You need to provide a password to create a public link, only protected links are allowed" : "Lotura publiko bat sortzeko pasahitza idatzi behar duzu, bakarrik babestutako loturak baimenduta daude",
    "Sharing %s failed, because sharing with links is not allowed" : "%s elkarbanatzeak huts egin du, lotura bidezko elkarbanatzea baimendua ez dagoelako",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Ezin izan da jarri iraungitze data. Konpartitzea ezin da iraungi konpartitu eta %s ondoren.",
    "Cannot set expiration date. Expiration date is in the past" : "Ezin da jarri iraungitze data. Iraungitze data iragan da.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "%s elkarbanaketa motorra  OCP\\Share_Backend interfazea inplementatu behar du ",
    "Sharing backend %s not found" : "Ez da %s elkarbanaketa motorra aurkitu",
    "Sharing backend for %s not found" : "Ez da %srako elkarbanaketa motorrik aurkitu",
    "Sharing %s failed, because resharing is not allowed" : "%s elkarbanatzeak huts egin du, ber-elkarbanatzea baimenduta ez dagoelako",
    "Sharing %s failed, because the file could not be found in the file cache" : "%s elkarbanatzeak huts egin du, fitxategia katxean aurkitu ez delako",
    "Open »%s«" : "Ireki »%s«",
    "Could not find category \"%s\"" : "Ezin da \"%s\" kategoria aurkitu",
    "Sunday" : "Igandea",
    "Monday" : "Astelehena",
    "Tuesday" : "Asteartea",
    "Wednesday" : "Asteazkena",
    "Thursday" : "Osteguna",
    "Friday" : "Ostirala",
    "Saturday" : "Larunbata",
    "Sun." : "Ig.",
    "Mon." : "Al.",
    "Tue." : "Ar.",
    "Wed." : "Az.",
    "Thu." : "Og.",
    "Fri." : "Ol.",
    "Sat." : "Lr.",
    "Su" : "Ig",
    "Mo" : "Al",
    "Tu" : "Ar",
    "We" : "Az",
    "Th" : "Og",
    "Fr" : "Ol",
    "Sa" : "Lr",
    "January" : "Urtarrila",
    "February" : "Otsaila",
    "March" : "Martxoa",
    "April" : "Apirila",
    "May" : "Maiatza",
    "June" : "Ekaina",
    "July" : "Uztaila",
    "August" : "Abuztua",
    "September" : "Iraila",
    "October" : "Urria",
    "November" : "Azaroa",
    "December" : "Abendua",
    "Jan." : "Urt.",
    "Feb." : "Ots.",
    "Mar." : "Mar.",
    "Apr." : "Api.",
    "May." : "Mai.",
    "Jun." : "Eka.",
    "Jul." : "Uzt.",
    "Aug." : "Abu.",
    "Sep." : "Ira.",
    "Oct." : "Urr.",
    "Nov." : "Aza.",
    "Dec." : "Abe.",
    "A valid username must be provided" : "Baliozko erabiltzaile izena eman behar da",
    "A valid password must be provided" : "Baliozko pasahitza eman behar da",
    "The username is already being used" : "Erabiltzaile izena dagoeneko erabiltzen ari da",
    "User disabled" : "Erabiltzaile desgaituta",
    "Login canceled by app" : "Aplikazioa saioa bertan behera utzi du",
    "Can't read file" : "Ezin da fitxategia irakurri",
    "Application is not enabled" : "Aplikazioa ez dago gaituta",
    "Authentication error" : "Autentifikazio errorea",
    "Token expired. Please reload page." : "Tokena iraungitu da. Mesedez birkargatu orria.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ez dago datubaseen (sqlite, mysql edo postgresql) driverrik instalatuta.",
    "Cannot write into \"config\" directory" : "Ezin da idatzi \"config\" karpetan",
    "Cannot write into \"apps\" directory" : "Ezin da idatzi \"apps\" karpetan",
    "Setting locale to %s failed" : "Lokala %sra ezartzeak huts egin du",
    "Please install one of these locales on your system and restart your webserver." : "Instalatu hauetako lokal bat zure sisteman eta berrabiarazi zure web zerbitzaria.",
    "Please ask your server administrator to install the module." : "Mesedez eskatu zure zerbitzariaren kudeatzaileari modulua instala dezan.",
    "PHP module %s not installed." : "PHPren %s modulua ez dago instalaturik.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hau ziur aski cache/accelerator batek eragin du, hala nola Zend OPcache edo eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduluak instalatu dira, baina oraindik faltan bezala markatuta daude?",
    "Please ask your server administrator to restart the web server." : "Mesedez eskatu zerbitzariaren kudeatzaileari web zerbitzaria berrabiarazteko.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 behar da",
    "Please upgrade your database version" : "Mesedez eguneratu zure datu basearen bertsioa",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Mesedez aldatu baimenak 0770ra beste erabiltzaileek karpetan sartu ezin izateko.",
    "Could not obtain lock type %d on \"%s\"." : "Ezin da lortu sarraia mota %d \"%s\"-an.",
    "Library %s with a version higher than %s is required - available version %s." : "%s liburutegiak %s baino bertsio handiagoa izan behar du - dagoen bertsioa %s.",
    "Library %s with a version lower than %s is required - available version %s." : "%s liburutegiak %s baino bertsio txikiagoa izan behar du - dagoen bertsioa %s.",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Encryption" : "Enkriptazio",
    "Tips & tricks" : "Aholkuak eta trikimailuak",
    "Sharing %s failed, because the user %s does not exist" : "%s elkarbanatzeak huts egin du, %s erabiltzailea existitzen ez delako",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s elkarbanatzeak huts egin du, %s erabiltzailea ez delako %s partaide den talderen bateko partaidea",
    "Sharing %s failed, because this item is already shared with %s" : "%s elkarbanatzeak huts egin du, dagoeneko %s erabiltzailearekin elkarbanatuta dagoelako",
    "Sharing %s failed, because the group %s does not exist" : "%s elkarbanatzeak huts egin du, %s taldea ez delako existitzen",
    "Sharing %s failed, because %s is not a member of the group %s" : "%s elkarbanatzeak huts egin du, %s ez delako %s taldearen partaidea",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s partekatzeak huts egin du, ezin da %s aurkitu, agian zerbitzaria orain ez dago eskuragarri.",
    "Share type %s is not valid for %s" : "%s elkarbanaketa mota ez da %srentzako egokia",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s elkarbanatzeak huts egin du, baimenak %sri emandakoak baino gehiago direlako",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s elkarbanatzeak huts egin du, %sren elkarbanaketa motorrak bere iturria aurkitu ezin duelako",
    "%s shared »%s« with you" : "%s-ek »%s« zurekin partekatu du",
    "%s via %s" : "%s %s bidez",
    "No app name specified" : "Ez da aplikazio izenik zehaztu"
},
"nplurals=2; plural=(n != 1);");
